A matrix containing simulated data points on a 20 X 20 grid at 20 time points. The rows correspond to the 400 spatial locations, and the columns, to the 20 time points.
ide_spatially_varyingA numeric matrix with 400 rows and 20 columns
[ide_locations] for a matrix containing the spatial locations corresponding to the rows of `ide_spatially_varying` and [ide_standard] for a similar data set generated from a standard ide model